==> morph_kgc-2.5.0.tar.gz: morph_kgc-2.5.0/docs/faq.md <==
# FAQ

#### Who develops Morph-KGC?
Morph-KGC was created by **[Julián Arenas-Guerrero](https://github.com/ArenasGuerreroJulian/)** in the **[Ontology Engineering Group](https://oeg.fi.upm.es)** at **[Universidad Politécnica de Madrid](https://www.upm.es/internacional)**.

#### How can I learn R2RML, RML, RML-star or RML+FnO?
The best starting point is the **[R2RML Recommendation](https://www.w3.org/TR/r2rml/)**. After that, you can continue with the **[RML](https://rml.io/specs/rml/)**, **[RML-star](https://kg-construct.github.io/rml-star-spec/)** or **[RML+FnO](https://kg-construct.github.io/fnml-spec/)** specifications.

#### I have some question related to R2RML, RML, RML-star or RML+FnO
The best place to get the answer is at **[Discussions for RML questions](https://github.com/kg-construct/rml-questions/discussions)**.

#### I installed Morph-KGC but I get an error saying some dependency is missing
To use relational databases and some data files it is required to install additional dependencies. You can check specific configuration options in **[Advanced Setup](https://morph-kgc.readthedocs.io/en/latest/documentation/#advanced-setup)**.

#### How do I submit a bug report?
Please, [open an issue](https://github.com/morph-kgc/morph-kgc/issues/new/choose) with a clear description of the bug. We will try to solve it as soon as possible.

#### I have a suggestion to improve the documentation
Please, [open an issue](https://github.com/morph-kgc/morph-kgc/issues/new/choose) providing a description of what documentation you believe needs to be fixed/improved and your suggestion. You can also contribute with a pull request to the **[GitHub repository](https://github.com/morph-kgc/morph-kgc/tree/main/docs)**.

#### Can I use Morph-KGC in a commercial project?
Yes! Morph-KGC is distributed under the **[Apache License 2.0](https://github.com/morph-kgc/morph-kgc/blob/main/LICENSE)** which allows  commercial use, modification, distribution, patent use and private use. Of course, we will appreciate it if you tell us that you are using Morph-KGC and can give us some details on how it is being used (as much as you can given confidentiality constraints). This would allow creating a database of projects where Morph-KGC is being used that could help us to request additional funding in the future, if needed.

#### I need commercial support
You are welcome to **[contact us](mailto:julian.arenas.guerrero@upm.es)**!

![OEG](assets/logo-oeg.png){ width="150" align=left } ![UPM](assets/logo-upm.png){ width="161" align=right }

==> morph_kgc-2.6.0.tar.gz: morph_kgc-2.6.0/docs/faq.md <==
# FAQ

#### Who develops Morph-KGC?
Morph-KGC was created by **[Julián Arenas-Guerrero](https://github.com/ArenasGuerreroJulian/)** in the **[Ontology Engineering Group](https://oeg.fi.upm.es)** at **[Universidad Politécnica de Madrid](https://www.upm.es/internacional)**.

#### How can I learn R2RML, RML, RML-star, RML+FNML or YARRRML?
The best starting point is the **[R2RML Recommendation](https://www.w3.org/TR/r2rml/)**. After that, you can continue with the **[RML-Core](https://w3id.org/rml/core/spec)**, **[RML-star](https://w3id.org/rml/star/spec)**, **[RML-FNML](https://w3id.org/rml/fnml/spec) or [YARRRML](https://rml.io/yarrrml/spec/)** specifications.

#### I have some question related to R2RML, RML, RML-star, RML-FNML or YARRRML
The best place to get the answer is at **[Discussions for RML questions](https://github.com/kg-construct/rml-questions/discussions)**.

#### I installed Morph-KGC but I get an error saying some dependency is missing
To use relational databases and some data files it is required to install additional dependencies. You can check specific configuration options in **[Advanced Setup](https://morph-kgc.readthedocs.io/en/latest/documentation/#advanced-setup)**.

#### How do I submit a bug report?
Please, [open an issue](https://github.com/morph-kgc/morph-kgc/issues/new/choose) with a clear description of the bug. We will try to solve it as soon as possible.

#### I have a suggestion to improve the documentation
Please, [open an issue](https://github.com/morph-kgc/morph-kgc/issues/new/choose) providing a description of what documentation you believe needs to be fixed/improved and your suggestion. You can also contribute with a pull request to the **[GitHub repository](https://github.com/morph-kgc/morph-kgc/tree/main/docs)**.

#### Can I use Morph-KGC in a commercial project?
Yes! Morph-KGC is distributed under the **[Apache License 2.0](https://github.com/morph-kgc/morph-kgc/blob/main/LICENSE)** which allows  commercial use, modification, distribution, patent use and private use. Of course, we will appreciate it if you tell us that you are using Morph-KGC and can give us some details on how it is being used (as much as you can given confidentiality constraints). This would allow creating a database of projects where Morph-KGC is being used that could help us to request additional funding in the future, if needed.

#### I need commercial support
You are welcome to **[contact us](mailto:julian.arenas.guerrero@upm.es)**!

![OEG](assets/logo-oeg.png){ width="150" align=left } ![UPM](assets/logo-upm.png){ width="161" align=right }
